"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tool_lib_1 = require("@kettil/tool-lib");
const chalk_1 = __importDefault(require("chalk"));
const spinner_1 = require("./spinner");
const levels = {
    log: (msg) => msg,
    error: chalk_1.default.red,
    info: chalk_1.default.green,
    debug: chalk_1.default.blue,
};
const maxLevelLength = Object.keys(levels).reduce((p, c) => Math.max(p, c.length), 0);
const getMessageLevel = (level) => levels[level](level.toUpperCase().padEnd(maxLevelLength));
const write = (type, message) => {
    process[type].write(`${message.trimEnd()}\n`);
};
const logging = (level, type) => (msg) => {
    const resume = spinner_1.spinnerBreak();
    const messages = tool_lib_1.isArray(msg) ? msg : msg.replace(/\n$/, '').split('\n');
    messages.forEach((m) => {
        write(type, `[${new Date().toISOString()}] ${level}: ${m}`);
    });
    resume();
};
const log = (msg) => write('stdout', tool_lib_1.isArray(msg) ? msg.join('\n') : msg);
const logger = ({ v, vvv }) => {
    const error = logging(getMessageLevel('error'), 'stderr');
    const info = logging(getMessageLevel('info'), 'stdout');
    const debug = logging(getMessageLevel('debug'), 'stdout');
    if (vvv) {
        return { log, error, info, debug };
    }
    if (v) {
        return { log, error, info, debug: tool_lib_1.dummy };
    }
    return { log, error: tool_lib_1.dummy, info: tool_lib_1.dummy, debug: tool_lib_1.dummy };
};
exports.default = logger;
